use Test::More tests => 1;

BEGIN {
use_ok( 'HTML::Latemp::GenMakeHelpers' );
}

diag( "Testing HTML::Latemp::GenMakeHelpers $HTML::Latemp::GenMakeHelpers::VERSION, Perl 5.008006, /usr/bin/perl5.8.6" );
